"""
    优才6w业务流程
"""

import pytest, time
from PageObjects.myClient_page import MyClientPage
from PageObjects.customersDetails_page import CustomersDetailsPage


@pytest.mark.usefixtures("myClient_page")
class TestTalentProcess:

    @pytest.mark.smoke
    def test_talentProcess(self, myClient_page):
        time.sleep(3)
        # 判断是否跳转到 我的客户 页面
        mcp = MyClientPage(myClient_page)
        mcp.is_myClient_exist()
        # 填写 客户信息 新增客户
        mcp.newClient()
        # 判断创建客户是否成功
        mcp.is_newClient_success()
        # 点击 列表手机号文本，跳转到客户详情页面
        mcp.click_mobile_text()

        # 判断是否跳转到 客户详情 页面
        cdp = CustomersDetailsPage(myClient_page)
        cdp.is_basicInfo_exist()
        # 进入 客户跟进 菜单，进行评分操作
        cdp.editor_mark()
        # 判断评分操作是否成功，分数需要大于80
        cdp.is_mark_success()
        # 进入合同页面，新建合同
        cdp.add_customer_contract()
        # 判断生成合同是否成功
        cdp.is_contract_success()
        # 创建订单
        cdp.add_order()
        # 判断创建订单是否成功
        cdp.is_order_success()
